@@ -45,14 +45,18 @@ void ScheduledOperationSkroogoid::init()
         setLayout(widgetLayout);
 
         Plasma::DataEngine* engine = dataEngine("skgdataengine");
-        if (engine->isValid())  engine->connectSource("Scheduled Operations", this);
+        if (engine->isValid()) {
+            engine->connectSource("Scheduled Operations", this);
+        }
     }
 }
 
 void ScheduledOperationSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData)
 {
-    if (sourceName != "Scheduled Operations") return;
-    SKGTRACEIN(1, "AdviceSkroogoid::dataUpdated");
+    if (sourceName != "Scheduled Operations") {
+        return;
+    }
+    SKGTRACEINFUNC(1);
 
     QHash<QString, QStringList> listData;
     for (int i = 0 ; i < engineData.keys().count() ; ++i) {
