@@ -52,18 +52,18 @@ SKGMonthlyPlugin::SKGMonthlyPlugin(QWidget* iWidget, QObject* iParent, const QVa
     m_currentBankDocument(NULL), m_mainPage(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGMonthlyPlugin::SKGMonthlyPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGMonthlyPlugin::~SKGMonthlyPlugin()
 {
-    SKGTRACEIN(10, "SKGMonthlyPlugin::~SKGMonthlyPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
 }
 
 bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGMonthlyPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = iDocument;
 
@@ -114,7 +114,7 @@ void SKGMonthlyPlugin::refreshMainPage()
 
 SKGTabPage* SKGMonthlyPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGMonthlyPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGMonthlyPluginWidget(m_currentBankDocument);
 }
 
