@@ -1685,7 +1685,7 @@ QString SKGImportPluginKmy::getKmyUniqueIdentifier(const SKGObjectBase& iObject)
     QString id;
     if (iObject.getID() != 0) {
         QString table = iObject.getRealTable();
-        if (table == "operation") {
+        if (table == "operation" || table == "suboperation") {
             // T000000000000003623
             id = 'T' % SKGServices::intToString(iObject.getID()).rightJustified(18, '0');
         } else if (table == "payee") {
