@@ -49,7 +49,7 @@ K_EXPORT_PLUGIN(SKGImportPluginMmbFactory("skrooge_import_mmb", "skrooge_import_
 SKGImportPluginMmb::SKGImportPluginMmb(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginMmb::SKGImportPluginMmb");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -59,15 +59,17 @@ SKGImportPluginMmb::~SKGImportPluginMmb()
 
 bool SKGImportPluginMmb::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginMmb::isImportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "MMB");
 }
 
 SKGError SKGImportPluginMmb::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportMmb::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     {
         QSqlDatabase originalDocument(QSqlDatabase::addDatabase("QSQLITE", "originalDocument"));
@@ -96,10 +98,14 @@ SKGError SKGImportPluginMmb::importFile()
                         err = unit.setName(attributes.at(1));
                         IFOK(err) {
                             QString symbol = attributes.at(2);
-                            if (symbol.isEmpty()) symbol = attributes.at(3);
+                            if (symbol.isEmpty()) {
+                                symbol = attributes.at(3);
+                            }
                             err = unit.setSymbol(symbol);
                         }
-                        if (!err && attributes.at(11) == "Y") err = unit.setType(SKGUnitObject::PRIMARY);
+                        if (!err && attributes.at(11) == "Y") {
+                            err = unit.setType(SKGUnitObject::PRIMARY);
+                        }
                         IFOKDO(err, unit.save())
 
                         mapUnit[attributes.at(0)] = unit;
@@ -127,7 +133,9 @@ SKGError SKGImportPluginMmb::importFile()
                         SKGBankObject bank(m_importer->getDocument());
                         IFOK(err) {
                             QString bankName = attributes.at(6);
-                            if (bankName.isEmpty()) bankName = "MMEX";
+                            if (bankName.isEmpty()) {
+                                bankName = "MMEX";
+                            }
                             err = bank.setName(bankName);
                         }
                         IFOKDO(err, bank.save())
@@ -255,7 +263,9 @@ SKGError SKGImportPluginMmb::importFile()
                             IFOKDO(err, acc.addOperation(op, true))
                             IFOK(err) {
                                 QString id = attributes.at(3);
-                                if (id != "-1") err = op.setPayee(mapPayee[id]);
+                                if (id != "-1") {
+                                    err = op.setPayee(mapPayee[id]);
+                                }
                             }
                             IFOKDO(err, op.setNumber(SKGServices::stringToInt(attributes.at(7))))
                             IFOKDO(err, op.setComment(attributes.at(8)))
@@ -282,14 +292,18 @@ SKGError SKGImportPluginMmb::importFile()
                                             QString id = attributes.at(10);
                                             if (id == "-1") {
                                                 id = attributes.at(9);
-                                                if (id != "-1") err = subop.setCategory(mapSubCategory[id]);
+                                                if (id != "-1") {
+                                                    err = subop.setCategory(mapSubCategory[id]);
+                                                }
                                             } else {
                                                 err = subop.setCategory(mapCategory[id]);
                                             }
                                         }
                                         IFOK(err) {
                                             double q = SKGServices::stringToDouble(attributes.at(5));
-                                            if (attributes.at(4) == "Withdrawal" || idTarget != "-1") q = -q;
+                                            if (attributes.at(4) == "Withdrawal" || idTarget != "-1") {
+                                                q = -q;
+                                            }
                                             err = subop.setQuantity(q);
                                         }
                                         IFOKDO(err, subop.save())
@@ -304,14 +318,18 @@ SKGError SKGImportPluginMmb::importFile()
                                                 QString id = attributesSubOp.at(2);
                                                 if (id == "-1") {
                                                     id = attributesSubOp.at(1);
-                                                    if (id != "-1") err = subop.setCategory(mapCategory[id]);
+                                                    if (id != "-1") {
+                                                        err = subop.setCategory(mapCategory[id]);
+                                                    }
                                                 } else {
                                                     err = subop.setCategory(mapSubCategory[id]);
                                                 }
                                             }
                                             IFOK(err) {
                                                 double q = SKGServices::stringToDouble(attributesSubOp.at(3));
-                                                if (attributes.at(4) == "Withdrawal" || idTarget != "-1") q = -q;
+                                                if (attributes.at(4) == "Withdrawal" || idTarget != "-1") {
+                                                    q = -q;
+                                                }
                                                 err = subop.setQuantity(q);
                                             }
                                             IFOKDO(err, subop.save())
@@ -604,7 +622,9 @@ SKGError SKGImportPluginMmb::importFile()
                                     QString id = attributes.at(3);
                                     if (id == "-1") {
                                         id = attributes.at(2);
-                                        if (id != "-1") err = bug.setCategory(mapCategory[id]);
+                                        if (id != "-1") {
+                                            err = bug.setCategory(mapCategory[id]);
+                                        }
                                     } else {
                                         err = bug.setCategory(mapSubCategory[id]);
                                     }
