@@ -59,7 +59,6 @@ SKGImportPluginMny::SKGImportPluginMny(QObject* iImporter, const QVariantList& i
 
     m_parameters["password"] = "";
     m_parameters["install_sunriise"] = 'N';
-    m_parameters["find_and_group_transfers"] = 'Y';
 }
 
 SKGImportPluginMny::~SKGImportPluginMny()
@@ -402,11 +401,15 @@ SKGError SKGImportPluginMny::importFile()
                             IFOKDO(err, operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation["date"].toULongLong()).date()))
                             IFOKDO(err, operationObj.setComment(operation["memo"].toString()))
                             IFOK(err) {
-                                // The number is something like "0     4220725"
+                                // The number is something like "0     4220725" or "1string"
                                 QString number = operation["number"].toString();
                                 if (!number.isEmpty()) {
-                                    QStringList ln = SKGServices::splitCSVLine(number, ' ');
-                                    err = operationObj.setNumber(SKGServices::stringToInt(ln.at(ln.count() - 1)));
+                                    if (number.startsWith(QLatin1Char('1'))) {
+                                        err = operationObj.setMode(number.right(number.count() - 1));
+                                    } else {
+                                        QStringList ln = SKGServices::splitCSVLine(number, ' ');
+                                        err = operationObj.setNumber(SKGServices::stringToInt(ln.at(ln.count() - 1)));
+                                    }
                                 }
                             }
                             IFOKDO(err, operationObj.setAttribute("t_imported", "T"))
@@ -418,6 +421,9 @@ SKGError SKGImportPluginMny::importFile()
                             IFOKDO(err, operationObj.setStatus(operation["reconciled"].toBool() ? SKGOperationObject::CHECKED :
                                                                operation["cleared"].toBool() ? SKGOperationObject::POINTED :
                                                                SKGOperationObject::NONE));
+                            if (operation["transfer"].toBool()) {
+                                IFOKDO(err, operationObj.setComment("#MNYTRANSFER#" % operationObj.getComment()))
+                            }
                             IFOKDO(err, operationObj.save(false))
 
                             double amount = operation["amount"].toDouble();
@@ -489,10 +495,9 @@ SKGError SKGImportPluginMny::importFile()
         IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
         // Step 6-Group operation
-        if (!err && m_parameters["find_and_group_transfers"] == "Y") {
-            int nbg = 0;
-            err = m_importer->findAndGroupTransfers(nbg, true);
-        }
+        int nbg = 0;
+        IFOKDO(err, m_importer->findAndGroupTransfers(nbg, QString("A.t_comment LIKE '#MNYTRANSFER#%' AND B.t_comment LIKE '#MNYTRANSFER#%'")))
+        IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("UPDATE operation SET t_comment=SUBSTR(t_comment, 14) WHERE t_comment LIKE '#MNYTRANSFER#%'"))
 
         IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
