@@ -260,6 +260,9 @@ void SKGCategoriesPluginWidget::onAddCategory()
             name = parentCat.getFullName() % OBJECTSEPARATOR % name;
         }
         IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), name, cat, false, true))
+
+        // Send message
+        IFOKDO(err, cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been created", cat.getDisplayName()), SKGDocument::Hidden));
     }
 
 // status bar
@@ -292,7 +295,12 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
             SKGCategoryObject catObj1(selection[0]);
             for (int i = 1; !err && i < nb; ++i) {
                 SKGCategoryObject catObj(selection[i]);
-                err = catObj1.merge(catObj);
+
+                // Send message
+                IFOKDO(err, catObj.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been merged with category '%2'", catObj1.getDisplayName(), catObj.getDisplayName()), SKGDocument::Hidden));
+
+                IFOKDO(err, catObj1.merge(catObj))
+
                 IFOKDO(err, getDocument()->stepForward(i))
             }
 
@@ -307,6 +315,9 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
             SKGCategoryObject cat(selection[i]);
             err = cat.setName(name);
             IFOKDO(err, cat.save())
+
+            // Send message
+            IFOKDO(err, cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been updated", cat.getDisplayName()), SKGDocument::Hidden));
         }
     }
     // status bar
