@@ -554,6 +554,9 @@ void SKGOperationPlugin::onGroupOperation()
                 IFOKDO(err, operationObj.save())
                 IFOKDO(err, main.load())
 
+                // Send message
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The operation '%1' has been grouped with '%2'", operationObj.getDisplayName(), main.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
@@ -584,6 +587,9 @@ void SKGOperationPlugin::onUngroupOperation()
                 IFOKDO(err, operationObj.setGroupOperation(operationObj))
                 IFOKDO(err, operationObj.save())
 
+                // Send message
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The operation '%1' has been ungrouped", operationObj.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
@@ -614,6 +620,9 @@ void SKGOperationPlugin::onSwitchToPointed()
                 IFOKDO(err, operationObj.setStatus(operationObj.getStatus() != SKGOperationObject::POINTED ? SKGOperationObject::POINTED : SKGOperationObject::NONE))
                 IFOKDO(err, operationObj.save())
 
+                // Send message
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The status of the operation '%1' has been changed", operationObj.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
@@ -646,6 +655,10 @@ void SKGOperationPlugin::onDuplicate()
                 IFOKDO(err, operationObj.duplicate(dup))
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
 
+                // Send message
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The duplicate operation '%1' has been added", dup.getDisplayName()), SKGDocument::Hidden));
+
+
                 listUUID.push_back(dup.getUniqueID());
             }
         }
@@ -683,6 +696,9 @@ void SKGOperationPlugin::onCreateTemplate()
                 IFOKDO(err, operationObj.duplicate(dup , QDate::currentDate(), true))
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
 
+                // Send message
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The template '%1' has been added", dup.getDisplayName()), SKGDocument::Hidden));
+
                 listUUID.push_back(dup.getUniqueID());
             }
         }
@@ -1388,6 +1404,9 @@ void SKGOperationPlugin::onMergeSubOperations()
             for (int i = 1; !err && i < nb; ++i) {
                 SKGOperationObject op2(selection.at(i));
                 err = op.mergeSuboperations(op2);
+
+                // Send message
+                IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user", "The sub operations of '%1' have been merged in the operation '%2'", op2.getDisplayName(), op.getDisplayName()), SKGDocument::Hidden));
             }
         }
     }
