@@ -286,6 +286,10 @@ void SKGScheduledPlugin::onScheduleOperation()
                 SKGOperationObject operationObj(selection.at(i));
                 SKGRecurrentOperationObject rop;
                 err = scheduleOperation(operationObj, rop);
+
+                // Send message
+                IFOKDO(err, m_currentBankDocument->sendMessage(i18nc("An information to the user", "The operation '%1' has been scheduled", operationObj.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 list.push_back(operationObj.getUniqueID());
             }
@@ -451,6 +455,9 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
                 IFOKDO(err, so1.setQuantity(amount - op.getCurrentAmount()))
                 IFOKDO(err, so1.save())
             }
+
+            // Send message
+            IFOKDO(err, op.getDocument()->sendMessage(i18nc("An information to the user", "The amount of the scheduled operation of '%1' have been updated", op.getDisplayName()), SKGDocument::Hidden));
         }
 
         // status bar
@@ -476,6 +483,9 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             SKGRecurrentOperationObject rop(m_currentBankDocument, id);
             IFOKDO(err, rop.setDate(SKGServices::stringToTime(newDate).date()))
             IFOKDO(err, rop.save())
+
+            // Send message
+            IFOKDO(err, rop.getDocument()->sendMessage(i18nc("An information to the user", "The date of the scheduled operation of '%1' have been updated", rop.getDisplayName()), SKGDocument::Hidden));
         }
 
         // status bar
@@ -502,7 +512,10 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             IFOKDO(err, rop.setPeriodIncrement(1))
             IFOKDO(err, rop.setDate(op.getDate()))
             IFOKDO(err, rop.setDate(rop.getNextDate()))
-            IFOKDO(err, rop.save(true, false))
+            IFOKDO(err, rop.save())
+
+            // Send message
+            IFOKDO(err, rop.getDocument()->sendMessage(i18nc("An information to the user", "The scheduled operation of '%1' have been added", rop.getDisplayName()), SKGDocument::Hidden));
 
             m_counterAdvice = 0;  // To force the update
         }
