@@ -466,7 +466,7 @@ void SKGUnitPluginWidget::onAddUnit()
         SKGUnitValueObject unitValueObject;
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit value creation for '%1'", untiname), err);
-            err = static_cast<SKGDocumentBank*>(getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject);
+            IFOKDO(err, static_cast<SKGDocumentBank*>(getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject))
         }
         // status bar
         IFOK(err) {
@@ -529,6 +529,10 @@ void SKGUnitPluginWidget::onModifyUnit()
                 err = unitObj.setDownloadSource(ui.kDownloadSource->text());
             }
             IFOKDO(err, unitObj.save())
+
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been updated", unitObj.getDisplayName()), SKGDocument::Hidden));
+
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
@@ -601,6 +605,9 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
             SKGUnitObject unit(selection.at(i));
             err = downloadUnitValue(unit, mode);
 
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been downloaded", unit.getDisplayName()), SKGDocument::Hidden));
+
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
@@ -627,6 +634,9 @@ void SKGUnitPluginWidget::onSimplify()
             SKGUnitObject unit(selection.at(i));
             err = unit.simplify();
 
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been simplified", unit.getDisplayName()), SKGDocument::Hidden));
+
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
