@@ -46,7 +46,7 @@
 #include "skgunitvalueobject.h"
 #include "skgbudgetruleobject.h"
 #include "skgbudgetobject.h"
-#include <skgsuboperationobject.h>
+#include "skgsuboperationobject.h"
 #include "skgtransactionmng.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
@@ -677,15 +677,14 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 
                         int nbDays = op.getDate().daysTo(QDate::currentDate());
                         if (nbDays != 0 && val2 != 0) {
-                            double gainperday = 100 * (exp(log(val1 / val2) / nbDays) - 1);
-                            gainperyear = 100 * (pow(1 + gainperday / 100, 365) - 1);
+                            double gainperday = 100.0 * expm1(log(val1 / val2) / static_cast<double>(nbDays));
+                            gainperyear = 100.0 * (pow(1.0 + gainperday / 100.0, 365.0) - 1);
                         }
                         toolTipString += i18nc("Noun", "Original amount=%1 (%2 = %3 / year)",
                                                KGlobal::locale()->formatMoney(val2, primaryUnit.Symbol, primaryUnit.NbDecimal),
                                                (gain >= 0 ? "+" : "-") % KGlobal::locale()->formatMoney(gain, "%", 2),
                                                (gainperyear >= 0 ? "+" : "-") % KGlobal::locale()->formatMoney(gainperyear, "%", 2));
                     } else {
-
                         if (!toolTipString.isEmpty()) {
                             toolTipString += "\n\n";
                         }
@@ -696,8 +695,8 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 
                         int nbDays = op.getDate().daysTo(QDate::currentDate());
                         if (nbDays != 0 && val2 != 0) {
-                            double gainperday = 100 * (exp(log(val1 / val2) / nbDays) - 1);
-                            gainperyear = 100 * (pow(1 + gainperday / 100, 365) - 1);
+                            double gainperday = 100.0 * expm1(log(val1 / val2) / static_cast<double>(nbDays));
+                            gainperyear = 100.0 * (pow(1.0 + gainperday / 100.0, 365.0) - 1);
                         }
 
                         QString sval1 = KGlobal::locale()->formatMoney(val1, primaryUnit.Symbol, primaryUnit.NbDecimal);
@@ -873,6 +872,9 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                     if (t_status != statusinitial) {
                         err = obj.setStatus(t_status);
                         IFOKDO(err, obj.save())
+
+                        // Send message
+                        IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The status of the operation '%1' has been changed", obj.getDisplayName()), SKGDocument::Hidden));
                     }
                 }
             } else if (m_recurrentoperationTable) {
@@ -886,14 +888,15 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err);
                     if (att == "i_warn_days") {
                         err = obj.warnEnabled(!obj.isWarnEnabled());
-                        IFOKDO(err, obj.save())
                     } else if (att == "i_auto_write_days") {
                         err = obj.autoWriteEnabled(!obj.isAutoWriteEnabled());
-                        IFOKDO(err, obj.save())
                     } else if (att == "i_nb_times") {
                         err = obj.timeLimit(!obj.hasTimeLimit());
-                        IFOKDO(err, obj.save())
                     }
+                    IFOKDO(err, obj.save())
+
+                    // Send message
+                    IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The recurrent operation '%1' has been updated", obj.getDisplayName()), SKGDocument::Hidden));
                 }
             } else if (m_budgetRuleTable) {
                 QString att = m_listAttibutes[iIndex.column()];
@@ -906,17 +909,17 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err);
                     if (att == "i_year") {
                         err = obj.enableYearCondition(!obj.isYearConditionEnabled());
-                        IFOKDO(err, obj.save())
                     } else if (att == "i_month") {
                         err = obj.enableMonthCondition(!obj.isMonthConditionEnabled());
-                        IFOKDO(err, obj.save())
                     } else if (att == "t_CATEGORYCONDITION") {
                         err = obj.enableCategoryCondition(!obj.isCategoryConditionEnabled());
-                        IFOKDO(err, obj.save())
                     } else if (att == "t_CATEGORY") {
                         err = obj.enableCategoryChange(!obj.isCategoryChangeEnabled());
-                        IFOKDO(err, obj.save())
                     }
+                    IFOKDO(err, obj.save())
+
+                    // Send message
+                    IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The budget rule '%1' has been updated", obj.getDisplayName()), SKGDocument::Hidden));
                 }
             } else if (m_budgetTable) {
                 QString att = m_listAttibutes[iIndex.column()];
@@ -928,8 +931,11 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
 
                     SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget update"), err);
                     if (att == "t_CATEGORY") {
-                        err = obj.enableSubCategoriesInclusion(!obj.isSubCategoriesInclusionEnabled());
+                        IFOKDO(err, obj.enableSubCategoriesInclusion(!obj.isSubCategoriesInclusionEnabled()))
                         IFOKDO(err, obj.save())
+
+                        // Send message
+                        IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The budget '%1' have been updated", obj.getDisplayName()), SKGDocument::Hidden));
                     }
                 }
             }
@@ -1024,6 +1030,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 
                 SKGCategoryObject child(getDocument(), o_id);
                 err = child.load();
+                QString oldName = child.getDisplayName();
                 IFOK(err) {
                     if (iParent.isValid()) {
                         err = child.setParentCategory(parentCategory);
@@ -1032,6 +1039,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
                     }
                 }
                 IFOKDO(err, child.save())
+
+                // Send message
+                IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The category '%1' has been moved to '%2'", oldName, child.getDisplayName()), SKGDocument::Hidden));
             }
         }
     } else if (iData->hasFormat("application/skg.payee.ids")) {
@@ -1050,6 +1060,10 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 
                 SKGPayeeObject child(getDocument(), o_id);
                 err = child.load();
+
+                // Send message
+                IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The payee '%1' has been merged with payee '%2'", child.getDisplayName(), parentPayee.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, parentPayee.merge(child))
             }
         }
@@ -1069,6 +1083,10 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 
                 SKGAccountObject child(getDocument(), o_id);
                 err = child.load();
+
+                // Send message
+                IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The account '%1' has been merged with account '%2'", child.getDisplayName(), parentAccount.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, parentAccount.merge(child))
             }
         }
@@ -1088,6 +1106,10 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 
                 SKGUnitObject child(getDocument(), o_id);
                 err = child.load();
+
+                // Send message
+                IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The unit '%1' has been merged with unit '%2'", child.getDisplayName(), parentUnit.getDisplayName()), SKGDocument::Hidden));
+
                 IFOKDO(err, parentUnit.merge(child))
             }
         }
@@ -1098,7 +1120,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 
         if (iParent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge trackers"), err);
-            SKGTrackerObject trackerUnit(getObject(iParent));
+            SKGTrackerObject parentTracker(getObject(iParent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -1107,7 +1129,11 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 
                 SKGTrackerObject child(getDocument(), o_id);
                 err = child.load();
-                IFOKDO(err, trackerUnit.merge(child))
+
+                // Send message
+                IFOKDO(err, parentTracker.getDocument()->sendMessage(i18nc("An information to the user", "The tracker '%1' has been merged with tracker '%2'", child.getDisplayName(), parentTracker.getDisplayName()), SKGDocument::Hidden));
+
+                IFOKDO(err, parentTracker.merge(child))
             }
         }
     }
