@@ -23,6 +23,7 @@
 
 #include <QDomDocument>
 #include <QHeaderView>
+#include <QMenu>
 
 #include "skgquerydelegate.h"
 #include "skgservices.h"
@@ -40,8 +41,13 @@ SKGQueryCreator::SKGQueryCreator(QWidget* iParent)
     ui.kList->setWordWrap(false);
     ui.kList->horizontalHeader()->setMovable(true);
 
+    ui.kToolHelp->setIcon(QIcon::fromTheme("dialog-information"));
+    ui.kCheckMode->setIcon(QIcon::fromTheme("arrow-down"));
+    ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
+    
+    connect(ui.kCheckMode, SIGNAL(clicked(bool)), this, SLOT(switchAdvancedSearchMode()));
     connect(ui.kList, SIGNAL(removeLine(int)), this, SLOT(removeLine(int)));
-
+    connect(ui.kFilterEdit, SIGNAL(returnPressed(QString)), this, SIGNAL(search()));
 
     addNewLine();
 }
@@ -51,11 +57,42 @@ SKGQueryCreator::~SKGQueryCreator()
     m_document = NULL;
 }
 
+bool SKGQueryCreator::advancedSearchMode() const
+{
+    return (!ui.kFilterEdit->isVisible());
+}
+
+void SKGQueryCreator::setAdvancedSearchMode(bool iAdvancedMode) const
+{
+    if (iAdvancedMode) {
+        ui.kToolHelp->hide();
+        ui.kFrmAdvanced->show();
+        ui.kFilterEdit->hide();
+        ui.kCheckMode->setIcon(QIcon::fromTheme("arrow-up"));
+	ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in simple mode"));
+    } else {
+        ui.kToolHelp->show();
+        ui.kFrmAdvanced->hide();
+        ui.kFilterEdit->show();
+        ui.kCheckMode->setIcon(QIcon::fromTheme("arrow-down"));
+	ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
+    }
+}
+
+void SKGQueryCreator::switchAdvancedSearchMode() const
+{
+    setAdvancedSearchMode(!advancedSearchMode());
+}
+
 void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute, bool iModeUpdate)
 {
     m_document = iDocument;
     m_table = iTable;
     m_updateMode = iModeUpdate;
+    m_attributes = iListAttribute;
+
+    setAdvancedSearchMode(m_updateMode);
+    ui.kCheckMode->setVisible(!m_updateMode);
 
 //     QString txt=(updateMode ? i18nc("Description", "Double click on a field name to add it to your modification definition.") : i18nc("Description", "Double click on a field name to add it to your search definition."))+'\n'+i18nc("Description", "Double click on a cell to modify it.");
 //     ui.kLabel->setComment ( "<html><body><b>"+SKGServices::stringToHtml ( txt ) +"</b></body></html>" );
@@ -94,14 +131,56 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
 
         ui.kList->setRowCount(0);
 
+        // Build list of attributes
+        QMenu* helpMenu = NULL;
+        if (!iModeUpdate) {
+            helpMenu = new QMenu();
+            {
+                QAction* act = helpMenu->addAction(i18nc("Operator contains", "or"));
+                act->setData(" +");
+                connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddText()));
+            }
+            {
+                QAction* act = helpMenu->addAction(i18nc("Operator contains", "but not"));
+                act->setData(" -");
+                connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddText()));
+            }
+            helpMenu->addSeparator();
+        }
         int nbCol = listAtts.count();
         for (int i = 0; i < nbCol; ++i) {
             QListWidgetItem* listItem = new QListWidgetItem(listAtts.at(i).icon, listAtts.at(i).display);
             ui.kListAtt->addItem(listItem);
             listItem->setData(Qt::UserRole, listAtts.at(i).name);
+
+            if (helpMenu) {
+                QAction* act = helpMenu->addAction(listAtts.at(i).icon, listAtts.at(i).display);
+                act->setData(listAtts.at(i).display);
+                connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddText()));
+            }
         }
         ui.kListAtt->sortItems();
         ui.kListAtt->setModelColumn(nbCol);
+        if (helpMenu) {
+            helpMenu->addSeparator();
+            {
+                QAction* act = helpMenu->addAction(i18nc("Operator contains", "Contains"));
+                act->setData(":");
+                connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddText()));
+            }
+            {
+                QAction* act = helpMenu->addAction(i18nc("Operator >", ">"));
+                act->setData(">");
+                connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddText()));
+            }
+            {
+                QAction* act = helpMenu->addAction(i18nc("Operator contains", "<"));
+                act->setData("<");
+                connect(act, SIGNAL(triggered(bool)), this, SLOT(onAddText()));
+            }
+            ui.kToolHelp->setMenu(helpMenu);
+        }
+
         connect(ui.kList->verticalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(removeLine(int)));
         connect(ui.kList->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(removeColumn(int)));
 
@@ -165,113 +244,132 @@ void SKGQueryCreator::setXMLCondition(const QString& iXML)
     ui.kList->setRowCount(0);
     ui.kList->setColumnCount(0);
 
-    int row = -1;
-    QDomNode l = root.firstChild();
-    while (!l.isNull()) {
-        QDomElement elementl = l.toElement();
-        if (!elementl.isNull()) {
-            // Add new line
-            addNewLine();
-            ++row;
+    if (root.tagName() == "element") {
+        // Mode advanced
+        setAdvancedSearchMode(true);
+        int row = -1;
+        QDomNode l = root.firstChild();
+        while (!l.isNull()) {
+            QDomElement elementl = l.toElement();
+            if (!elementl.isNull()) {
+                // Add new line
+                addNewLine();
+                ++row;
 
-            QDomNode n = elementl.firstChild();
-            while (!n.isNull()) {
-                QDomElement element = n.toElement();
-                if (!element.isNull()) {
-                    QString attribute = element.attribute("attribute");
-                    int idx = getIndexQueryColumn(attribute, row);
-                    if (idx >= 0) {
-                        QDomDocument doc2("SKGML");
-                        QDomElement root2 = doc2.createElement("element");
-                        doc2.appendChild(root2);
-                        root2.setAttribute("operator", element.attribute("operator"));
-                        root2.setAttribute("value", element.attribute("value"));
-                        root2.setAttribute("value2", element.attribute("value2"));
-                        root2.setAttribute("att2", element.attribute("att2"));
-                        root2.setAttribute("att2s", element.attribute("att2s"));
-                        QTableWidgetItem* it = ui.kList->item(row, idx);
-                        if (it) {
-                            QString xml = doc2.toString();
+                QDomNode n = elementl.firstChild();
+                while (!n.isNull()) {
+                    QDomElement element = n.toElement();
+                    if (!element.isNull()) {
+                        QString attribute = element.attribute("attribute");
+                        int idx = getIndexQueryColumn(attribute, row);
+                        if (idx >= 0) {
+                            QDomDocument doc2("SKGML");
+                            QDomElement root2 = doc2.createElement("element");
+                            doc2.appendChild(root2);
+                            root2.setAttribute("operator", element.attribute("operator"));
+                            root2.setAttribute("value", element.attribute("value"));
+                            root2.setAttribute("value2", element.attribute("value2"));
+                            root2.setAttribute("att2", element.attribute("att2"));
+                            root2.setAttribute("att2s", element.attribute("att2s"));
+                            QTableWidgetItem* it = ui.kList->item(row, idx);
+                            if (it) {
+                                QString xml = doc2.toString();
 
-                            it->setText(SKGPredicatCreator::getTextFromXml(xml));
-                            it->setData(Qt::UserRole, xml);
+                                it->setText(SKGPredicatCreator::getTextFromXml(xml));
+                                it->setData(Qt::UserRole, xml);
+                            }
                         }
                     }
+                    n = n.nextSibling();
                 }
-                n = n.nextSibling();
             }
+            l = l.nextSibling();
         }
-        l = l.nextSibling();
-    }
 
-    addNewLine();
+        addNewLine();
+    } else  {
+        // Mode simple
+        setAdvancedSearchMode(false);
+        ui.kFilterEdit->setText(root.attribute("query"));
+    }
 }
 
 QString SKGQueryCreator::getXMLCondition()
 {
     QString output;
-    QHeaderView* hHeader = ui.kList->horizontalHeader();
-    if (hHeader) {
-        QDomDocument doc("SKGML");
-        QDomElement element = doc.createElement("element");
-        doc.appendChild(element);
+    if (advancedSearchMode()) {
+        // Mode advanced
+        QHeaderView* hHeader = ui.kList->horizontalHeader();
+        if (hHeader) {
+            QDomDocument doc("SKGML");
+            QDomElement element = doc.createElement("element");
+            doc.appendChild(element);
 
-        element.appendChild(doc.createComment("OR"));
+            element.appendChild(doc.createComment("OR"));
 
-        bool empty = true;
-        int nbRow = ui.kList->rowCount();
-        int nbCol = hHeader->count();
-        for (int j = 0; j < nbRow; ++j) {
-            QDomElement elementLine = doc.createElement("element");
-            element.appendChild(elementLine);
+            bool empty = true;
+            int nbRow = ui.kList->rowCount();
+            int nbCol = hHeader->count();
+            for (int j = 0; j < nbRow; ++j) {
+                QDomElement elementLine = doc.createElement("element");
+                element.appendChild(elementLine);
 
-            elementLine.appendChild(doc.createComment("AND"));
+                elementLine.appendChild(doc.createComment("AND"));
 
-            bool atLeastOne = false;
-            for (int i = 0; i < nbCol; ++i) {
-                int iRealPos = hHeader->logicalIndex(i);
-                QTableWidgetItem* it = ui.kList->item(j, iRealPos);
-                if (it) {
-                    QString co = it->data(Qt::UserRole).toString();
-                    if (!co.isEmpty()) {
-                        QDomElement elementElement = doc.createElement("element");
-                        elementLine.appendChild(elementElement);
+                bool atLeastOne = false;
+                for (int i = 0; i < nbCol; ++i) {
+                    int iRealPos = hHeader->logicalIndex(i);
+                    QTableWidgetItem* it = ui.kList->item(j, iRealPos);
+                    if (it) {
+                        QString co = it->data(Qt::UserRole).toString();
+                        if (!co.isEmpty()) {
+                            QDomElement elementElement = doc.createElement("element");
+                            elementLine.appendChild(elementElement);
 
-                        QTableWidgetItem* it_h = ui.kList->horizontalHeaderItem(iRealPos);
-                        QString attname = it_h->data(Qt::UserRole).toString();
+                            QTableWidgetItem* it_h = ui.kList->horizontalHeaderItem(iRealPos);
+                            QString attname = it_h->data(Qt::UserRole).toString();
 
-                        QDomDocument doc2("SKGML");
-                        doc2.setContent(co);
-                        QDomElement root2 = doc2.documentElement();
+                            QDomDocument doc2("SKGML");
+                            doc2.setContent(co);
+                            QDomElement root2 = doc2.documentElement();
 
-                        elementElement.setAttribute("attribute", attname);
-                        elementElement.setAttribute("operator", root2.attribute("operator"));
-                        if (root2.hasAttribute("value")) {
-                            elementElement.setAttribute("value", root2.attribute("value"));
+                            elementElement.setAttribute("attribute", attname);
+                            elementElement.setAttribute("operator", root2.attribute("operator"));
+                            if (root2.hasAttribute("value")) {
+                                elementElement.setAttribute("value", root2.attribute("value"));
+                            }
+                            if (root2.hasAttribute("value2")) {
+                                elementElement.setAttribute("value2", root2.attribute("value2"));
+                            }
+                            if (root2.hasAttribute("att2")) {
+                                elementElement.setAttribute("att2", root2.attribute("att2"));
+                            }
+                            if (root2.hasAttribute("att2s")) {
+                                elementElement.setAttribute("att2s", root2.attribute("att2s"));
+                            }
+
+                            atLeastOne = true;
+                            empty = false;
                         }
-                        if (root2.hasAttribute("value2")) {
-                            elementElement.setAttribute("value2", root2.attribute("value2"));
-                        }
-                        if (root2.hasAttribute("att2")) {
-                            elementElement.setAttribute("att2", root2.attribute("att2"));
-                        }
-                        if (root2.hasAttribute("att2s")) {
-                            elementElement.setAttribute("att2s", root2.attribute("att2s"));
-                        }
-
-                        atLeastOne = true;
-                        empty = false;
                     }
                 }
-            }
 
-            if (!atLeastOne) {
-                element.removeChild(elementLine);
+                if (!atLeastOne) {
+                    element.removeChild(elementLine);
+                }
+            }
+            if (!empty) {
+                output = doc.toString();
             }
         }
-        if (!empty) {
-            output = doc.toString();
-        }
+    } else {
+        // Mode simple
+        QDomDocument doc("SKGML");
+        QDomElement element = doc.createElement("simple");
+        element.setAttribute("query", ui.kFilterEdit->text());
+        element.setAttribute("sql", SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(ui.kFilterEdit->text()), m_attributes, m_document));
+        doc.appendChild(element);
+        output = doc.toString();
     }
 
     return output;
@@ -300,6 +398,14 @@ void SKGQueryCreator::onCloseEditor()
     resizeColumns();
 }
 
+void SKGQueryCreator::onAddText()
+{
+    QAction* act = qobject_cast< QAction* >(sender());
+    if (act) {
+        ui.kFilterEdit->insert(act->data().toString());
+    }
+}
+
 void SKGQueryCreator::onAddColumn()
 {
     QList<QListWidgetItem*> selection = ui.kListAtt->selectedItems();
