@@ -104,9 +104,32 @@ public Q_SLOTS:
      */
     virtual void addNewLine();
 
+    /**
+     * Set/unset the advanced search mode
+     * @param iAdvancedMode the mode
+     */
+    virtual void setAdvancedSearchMode(bool iAdvancedMode) const;
+
+    /**
+     * Get the advanced search mode
+     */
+    virtual bool advancedSearchMode() const;
+
+    /**
+     * Switch the advanced search mode
+     */
+    virtual void switchAdvancedSearchMode() const;
+    
+Q_SIGNALS:
+    /**
+     * Emmited when the search is triggered
+     */  
+    void search();
+
 private Q_SLOTS:
     void onCloseEditor();
     void onAddColumn();
+    void onAddText();
 private:
     Q_DISABLE_COPY(SKGQueryCreator)
 
@@ -118,6 +141,7 @@ private:
     SKGDocument* m_document;
     QString m_table;
     bool m_updateMode;
+    QStringList m_attributes;
 };
 
 #endif  // SKGQUERYCREATOR_H
