@@ -75,7 +75,7 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
             err = oPayee.setName(iName);
             IFOKDO(err, oPayee.save())
 
-            if (!err && iSendPopupMessageOnCreation && iDocument) {
+            if (!err && iSendPopupMessageOnCreation) {
                 err = iDocument->sendMessage(i18nc("Information message", "Payee '%1' has been created" , iName), SKGDocument::Positive);
             }
         }
@@ -125,7 +125,7 @@ SKGError SKGPayeeObject::merge(const SKGPayeeObject& iPayee)
         IFOKDO(err, op.save(true, false))
     }
 
-    IFOKDO(err, iPayee.remove())
+    IFOKDO(err, iPayee.remove(false))
     return err;
 }
 
