@@ -198,6 +198,7 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
             doc->executeSelectSqliteOrder(sql, result);
             if (result.count() == 2) {
                 QStringList r = result.at(1);
+                alarm.Raised = (r.at(0) == "1");
                 alarm.Message = r.at(3);
                 alarm.Amount = SKGServices::stringToDouble(r.at(1));
                 alarm.Limit = SKGServices::stringToDouble(r.at(2));
@@ -531,156 +532,160 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
     QDomDocument doc("SKGML");
     doc.setContent(iXML);
     QDomElement root = doc.documentElement();
+    if (root.tagName() == "element" || iType != SEARCH) {
+        // Mode advanced
+        QDomNode l = root.firstChild();
+        while (!l.isNull()) {
+            QDomElement elementl = l.toElement();
+            if (!elementl.isNull()) {
+                QString lineDescription;
 
-    QDomNode l = root.firstChild();
-    while (!l.isNull()) {
-        QDomElement elementl = l.toElement();
-        if (!elementl.isNull()) {
-            QString lineDescription;
-
-            QDomNode n = elementl.firstChild();
-            bool parenthesisNeeded = false;
-            while (!n.isNull()) {
-                QDomElement element = n.toElement();
-                if (!element.isNull()) {
-                    // Build element description
-                    QString elementDescription;
-                    QString attribute = element.attribute("attribute");
-                    QString propName;
-                    if (iSQL) {
-                        attribute = SKGServices::stringToSqlString(attribute);
-                        if (attribute.startsWith(QLatin1String("p_"))) {
-                            // Case property
-                            propName = attribute.right(attribute.length() - 2);
-                            if (iType == SEARCH) {
-                                attribute = "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND i_PROPVALUE";
-                            } else {
-                                attribute = "t_value";
-                            }
-                        }
-
-                        QString part = element.attribute("operator");
-                        part = part.replace("#V1#", SKGServices::stringToSqlString(element.attribute("value")));
-                        part = part.replace("#V1S#", SKGServices::stringToSqlString(element.attribute("value")));
-                        part = part.replace("#V2#", SKGServices::stringToSqlString(element.attribute("value2")));
-                        part = part.replace("#V2S#", SKGServices::stringToSqlString(element.attribute("value2")));
-                        part = part.replace("#DF#", SKGServices::stringToSqlString(element.attribute("value2")));
-                        part = part.replace("#OP#", SKGServices::stringToSqlString(element.attribute("operator2")));
-
-                        elementDescription += part;
-                    } else {
-                        attribute = "operation." % attribute;
-                        if (iDocument) {
-                            attribute = iDocument->getDisplay(attribute);
-                        }
-
-                        if (iType != ALARM && iType != APPLYTEMPLATE) {
-                            elementDescription = attribute;
-                            elementDescription += ' ';
-                        }
-
-                        QString tmp = element.attribute("att2s");
-                        if (tmp.isEmpty()) {
-                            tmp = element.attribute("operator2");
-                        }
-                        QString part = SKGRuleObject::getDisplayForOperator(element.attribute("operator"),
-                                       element.attribute("value"),
-                                       element.attribute("value2"),
-                                       tmp);
-
-                        elementDescription += part;
-                    }
-
-                    elementDescription = elementDescription.replace("#ATT#", attribute);
-
-                    // Att2
-                    QString attribute2 = element.attribute("att2");
-                    if (iSQL) {
-                        attribute2 = SKGServices::stringToSqlString(attribute2);
-                        if (attribute2.startsWith(QLatin1String("p_"))) {
-                            QString propertyName = attribute2.right(attribute2.length() - 2);
-                            attribute2 = "IFNULL((SELECT op2.i_PROPVALUE FROM v_operation_prop op2 WHERE op2.id=v_operation_prop.id AND op2.i_PROPPNAME='" % SKGServices::stringToSqlString(propertyName) % "'),'')";
-                        }
-
-                        if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
-                            attribute2 = "(SELECT " % attribute2 %  " FROM v_operation_prop WHERE i_PROPPID=parameters.id)";
-                        }
-                    }
-                    elementDescription = elementDescription.replace("#ATT2#", attribute2);
-
-                    // Add it to line description
-                    if (iSQL) {
-                        if (iType == UPDATE) {
-                            if (!iFullUpdate) {
-                                output.push_back(elementDescription);
-                            } else {
-                                QString sqlOrder;
-                                if (attribute == "t_REALCATEGORY") {
-                                    elementDescription.replace(attribute, "t_fullname");
-
-                                    QString parentcat;
-                                    QString cat = element.attribute("value");
-                                    bool stop = false;
-                                    while (!stop) {
-                                        int posSeparator = cat.indexOf(OBJECTSEPARATOR);
-                                        if (posSeparator == -1) {
-                                            if (parentcat.isEmpty()) {
-                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "', 0)");
-                                            } else {
-                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
-                                            }
-                                            stop = true;
-                                        } else {
-                                            // Get first and second parts of the branch
-                                            QString first = cat.mid(0, posSeparator);
-                                            QString second = cat.mid(posSeparator + QString(OBJECTSEPARATOR).length(), cat.length() - posSeparator - QString(OBJECTSEPARATOR).length());
-                                            if (parentcat.isEmpty()) {
-                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "', 0)");
-                                            } else {
-                                                output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
-                                            }
-
-                                            if (parentcat.isEmpty()) {
-                                                parentcat = first;
-                                            } else {
-                                                parentcat = parentcat % OBJECTSEPARATOR % first;
-                                            }
-                                            cat = second;
-                                        }
-                                    }
-                                    output.push_back("UPDATE suboperation set r_category_id=(SELECT id FROM category WHERE " % elementDescription % ") WHERE i_tmp=1");
-                                } else if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
-                                    output.push_back("INSERT OR IGNORE INTO parameters (t_uuid_parent, t_name, i_tmp) SELECT o.id||'-operation', '" % SKGServices::stringToSqlString(propName) % "', 1 FROM operation o WHERE o.i_tmp=1");
-                                    output.push_back("UPDATE parameters set " % elementDescription % " WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND NOT(" % elementDescription % ')');
-                                    output.push_back("DELETE FROM parameters WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND t_value=''");
+                QDomNode n = elementl.firstChild();
+                bool parenthesisNeeded = false;
+                while (!n.isNull()) {
+                    QDomElement element = n.toElement();
+                    if (!element.isNull()) {
+                        // Build element description
+                        QString elementDescription;
+                        QString attribute = element.attribute("attribute");
+                        QString propName;
+                        if (iSQL) {
+                            attribute = SKGServices::stringToSqlString(attribute);
+                            if (attribute.startsWith(QLatin1String("p_"))) {
+                                // Case property
+                                propName = attribute.right(attribute.length() - 2);
+                                if (iType == SEARCH) {
+                                    attribute = "i_PROPPNAME='" % SKGServices::stringToSqlString(propName) % "' AND i_PROPVALUE";
                                 } else {
-                                    output.push_back("UPDATE v_operation_prop set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
+                                    attribute = "t_value";
                                 }
                             }
-                        } else if (iType == ALARM) {
-                            output.push_back("SELECT " % elementDescription % " FROM v_suboperation_consolidated WHERE #WC#");
-                        } else if (iType == APPLYTEMPLATE) {
-                            output.push_back(element.attribute("value"));
+
+                            QString part = element.attribute("operator");
+                            part = part.replace("#V1#", SKGServices::stringToSqlString(element.attribute("value")));
+                            part = part.replace("#V1S#", SKGServices::stringToSqlString(element.attribute("value")));
+                            part = part.replace("#V2#", SKGServices::stringToSqlString(element.attribute("value2")));
+                            part = part.replace("#V2S#", SKGServices::stringToSqlString(element.attribute("value2")));
+                            part = part.replace("#DF#", SKGServices::stringToSqlString(element.attribute("value2")));
+                            part = part.replace("#OP#", SKGServices::stringToSqlString(element.attribute("operator2")));
+
+                            elementDescription += part;
+                        } else {
+                            attribute = "operation." % attribute;
+                            if (iDocument) {
+                                attribute = iDocument->getDisplay(attribute);
+                            }
+
+                            if (iType != ALARM && iType != APPLYTEMPLATE) {
+                                elementDescription = attribute;
+                                elementDescription += ' ';
+                            }
+
+                            QString tmp = element.attribute("att2s");
+                            if (tmp.isEmpty()) {
+                                tmp = element.attribute("operator2");
+                            }
+                            QString part = SKGRuleObject::getDisplayForOperator(element.attribute("operator"),
+                                           element.attribute("value"),
+                                           element.attribute("value2"),
+                                           tmp);
+
+                            elementDescription += part;
                         }
-                    }
 
-                    if (!lineDescription.isEmpty()) {
-                        lineDescription += (iType == UPDATE ? " , " : (iSQL ? " AND " : i18nc("logical operator in a search query", " and ")));
-                        parenthesisNeeded = true;
-                    }
-                    lineDescription += elementDescription;
-                }
-                n = n.nextSibling();
-            }
+                        elementDescription = elementDescription.replace("#ATT#", attribute);
 
-            if (!(iType != SEARCH && iSQL) && !lineDescription.isEmpty()) {
-                if (iType == SEARCH && parenthesisNeeded) {
-                    lineDescription = '(' % lineDescription % ')';
+                        // Att2
+                        QString attribute2 = element.attribute("att2");
+                        if (iSQL) {
+                            attribute2 = SKGServices::stringToSqlString(attribute2);
+                            if (attribute2.startsWith(QLatin1String("p_"))) {
+                                QString propertyName = attribute2.right(attribute2.length() - 2);
+                                attribute2 = "IFNULL((SELECT op2.i_PROPVALUE FROM v_operation_prop op2 WHERE op2.id=v_operation_prop.id AND op2.i_PROPPNAME='" % SKGServices::stringToSqlString(propertyName) % "'),'')";
+                            }
+
+                            if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
+                                attribute2 = "(SELECT " % attribute2 %  " FROM v_operation_prop WHERE i_PROPPID=parameters.id)";
+                            }
+                        }
+                        elementDescription = elementDescription.replace("#ATT2#", attribute2);
+
+                        // Add it to line description
+                        if (iSQL) {
+                            if (iType == UPDATE) {
+                                if (!iFullUpdate) {
+                                    output.push_back(elementDescription);
+                                } else {
+                                    QString sqlOrder;
+                                    if (attribute == "t_REALCATEGORY") {
+                                        elementDescription.replace(attribute, "t_fullname");
+
+                                        QString parentcat;
+                                        QString cat = element.attribute("value");
+                                        bool stop = false;
+                                        while (!stop) {
+                                            int posSeparator = cat.indexOf(OBJECTSEPARATOR);
+                                            if (posSeparator == -1) {
+                                                if (parentcat.isEmpty()) {
+                                                    output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "', 0)");
+                                                } else {
+                                                    output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                                }
+                                                stop = true;
+                                            } else {
+                                                // Get first and second parts of the branch
+                                                QString first = cat.mid(0, posSeparator);
+                                                QString second = cat.mid(posSeparator + QString(OBJECTSEPARATOR).length(), cat.length() - posSeparator - QString(OBJECTSEPARATOR).length());
+                                                if (parentcat.isEmpty()) {
+                                                    output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "', 0)");
+                                                } else {
+                                                    output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
+                                                }
+
+                                                if (parentcat.isEmpty()) {
+                                                    parentcat = first;
+                                                } else {
+                                                    parentcat = parentcat % OBJECTSEPARATOR % first;
+                                                }
+                                                cat = second;
+                                            }
+                                        }
+                                        output.push_back("UPDATE suboperation set r_category_id=(SELECT id FROM category WHERE " % elementDescription % ") WHERE i_tmp=1");
+                                    } else if (element.attribute("attribute").startsWith(QLatin1String("p_"))) {
+                                        output.push_back("INSERT OR IGNORE INTO parameters (t_uuid_parent, t_name, i_tmp) SELECT o.id||'-operation', '" % SKGServices::stringToSqlString(propName) % "', 1 FROM operation o WHERE o.i_tmp=1");
+                                        output.push_back("UPDATE parameters set " % elementDescription % " WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND NOT(" % elementDescription % ')');
+                                        output.push_back("DELETE FROM parameters WHERE i_tmp=1 AND t_name='" % SKGServices::stringToSqlString(propName) % "' AND t_value=''");
+                                    } else {
+                                        output.push_back("UPDATE v_operation_prop set " % elementDescription % " WHERE i_tmp=1 AND NOT(" % elementDescription % ')');
+                                    }
+                                }
+                            } else if (iType == ALARM) {
+                                output.push_back("SELECT " % elementDescription % " FROM v_suboperation_consolidated WHERE #WC#");
+                            } else if (iType == APPLYTEMPLATE) {
+                                output.push_back(element.attribute("value"));
+                            }
+                        }
+
+                        if (!lineDescription.isEmpty()) {
+                            lineDescription += (iType == UPDATE ? " , " : (iSQL ? " AND " : i18nc("logical operator in a search query", " and ")));
+                            parenthesisNeeded = true;
+                        }
+                        lineDescription += elementDescription;
+                    }
+                    n = n.nextSibling();
+                }
+
+                if (!(iType != SEARCH && iSQL) && !lineDescription.isEmpty()) {
+                    if (iType == SEARCH && parenthesisNeeded) {
+                        lineDescription = '(' % lineDescription % ')';
+                    }
+                    output.push_back(lineDescription);
                 }
-                output.push_back(lineDescription);
             }
+            l = l.nextSibling();
         }
-        l = l.nextSibling();
+    } else {
+        output.push_back(root.attribute(iSQL ? "sql" : "query"));
     }
 
     if (iFullUpdate) {
