@@ -57,6 +57,26 @@ const SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGObjectBa
     return *this;
 }
 
+SKGError SKGSubOperationObject::setDate(const QDate& iDate)
+{
+    return setAttribute("d_date", iDate.isValid() ? SKGServices::dateToSqlString(QDateTime(iDate)) : "");
+}
+
+QDate SKGSubOperationObject::getDate() const
+{
+    return SKGServices::stringToTime(getAttribute("d_date")).date();
+}
+
+SKGError SKGSubOperationObject::setOrder(int iOrder)
+{
+    return setAttribute("i_order", SKGServices::intToString(iOrder));
+}
+
+int SKGSubOperationObject::getOrder() const
+{
+    return SKGServices::stringToInt(getAttribute("i_order"));
+}
+
 SKGError SKGSubOperationObject::setComment(const QString& iComment)
 {
     return setAttribute("t_comment", iComment);
@@ -85,7 +105,12 @@ SKGError SKGSubOperationObject::getParentOperation(SKGOperationObject& oOperatio
 
 SKGError SKGSubOperationObject::setParentOperation(const SKGOperationObject& iOperation)
 {
-    return setAttribute("rd_operation_id", SKGServices::intToString(iOperation.getID()));
+    SKGError err;
+    if (!getDate().isValid()) {
+        err = setDate(iOperation.getDate());
+    }
+    IFOKDO(err, setAttribute("rd_operation_id", SKGServices::intToString(iOperation.getID())))
+    return err;
 }
 
 
@@ -131,9 +156,13 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker, boo
 SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
 {
     QString idS = getAttribute("r_refund_id");
-    if (idS.isEmpty()) idS = '0';
+    if (idS.isEmpty()) {
+        idS = '0';
+    }
     SKGError err;
-    if (getDocument() && idS != "0") err = getDocument()->getObject("v_refund", "id=" % idS, oTracker);
+    if (getDocument() && idS != "0") {
+        err = getDocument()->getObject("v_refund", "id=" % idS, oTracker);
+    }
     return err;
 }
 
