@@ -130,7 +130,7 @@ SKGError SKGTrackerObject::merge(const SKGTrackerObject& iTracker)
         IFOKDO(err, op.save(true, false))
     }
 
-    IFOKDO(err, iTracker.remove())
+    IFOKDO(err, iTracker.remove(false))
     return err;
 }
 
