@@ -93,6 +93,25 @@ public:
      **/
     virtual void setModel(SKGObjectModelBase* iModel);
 
+public Q_SLOTS:
+    /**
+     * @brief Set the filter. This filter disable the "show" menu
+     *
+     * @param iIcon the icon
+     * @param iText the text to display
+     * @param iWhereClause the where clause
+     * @return void
+     **/
+    virtual void setFilter(const KIcon& iIcon, const QString& iText, const QString& iWhereClause);
+
+    /**
+     * @brief Reset the filter
+     *
+     * @param iModel the model
+     * @return void
+     **/
+    virtual void resetFilter();
+
 private Q_SLOTS:
     void pageChanged();
     void onFilterChanged();
