@@ -2043,7 +2043,7 @@ void SKGMainPanel::resetDefaultState()
         QString name = toSave->getDefaultStateAttribute();
         if (!name.isEmpty()) {
             SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Reset default state"), err);
-            err = getDocument()->setParameter(name, "<!DOCTYPE SKGML>");
+            IFOKDO(err, getDocument()->setParameter(name, "<!DOCTYPE SKGML>"))
 
             // Refresh panel
             IFOK(err) toSave->setState("");
