@@ -657,8 +657,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                                      formatMoney(sum),
                                      formatMoney(min),
                                      formatMoney(average),
-                                     formatMoney(max)
-                                    );
+                                     formatMoney(max));
                     } else {
                         return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
                                      getDocument()->getDisplay(m_groupby),
@@ -870,7 +869,7 @@ bool SKGObjectModelBase::setData(const QModelIndex& iIndex, const QVariant& iVal
             SKGNodeObject obj(getObject(iIndex));
             QString name = iValue.toString();
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", name), err);
-            err = obj.setName(name);
+            IFOKDO(err, err = obj.setName(name))
             IFOKDO(err, obj.save())
         } else {
             SKGObjectBase obj(getObject(iIndex));
@@ -878,7 +877,7 @@ bool SKGObjectModelBase::setData(const QModelIndex& iIndex, const QVariant& iVal
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Update object"), err);
             SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID());  // To be sure this is not a complex object
             QString att = m_listAttibutes.at(iIndex.column());
-            err = obj2.setAttribute(att, att.startsWith(QLatin1String("d_")) && iValue.canConvert<QDateTime>() ? SKGServices::dateToSqlString(iValue.toDateTime()) : iValue.toString());
+            IFOKDO(err, obj2.setAttribute(att, att.startsWith(QLatin1String("d_")) && iValue.canConvert<QDateTime>() ? SKGServices::dateToSqlString(iValue.toDateTime()) : iValue.toString()))
             IFOKDO(err, obj2.save())
         }
 
@@ -1011,6 +1010,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                 // Set parent
                 SKGNodeObject child(getDocument(), o_id);
                 err = child.load();
+                QString oldName = child.getDisplayName();
                 IFOK(err) {
                     if (parentIndex.isValid()) {
                         err = child.setParentNode(parentNode);
@@ -1024,6 +1024,9 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
 
                 // Save
                 IFOKDO(err, child.save())
+
+                // Send message
+                IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The bookmark '%1' has been moved to '%2'", oldName, child.getDisplayName()), SKGDocument::Hidden));
             }
         }
     }
