@@ -55,15 +55,17 @@ void SKGProgressBar::setValue(int iValue)
 {
     QProgressBar::setValue(iValue);
     if (m_negative <= m_positive) {
-        if (iValue <= m_negative) setStyleSheet(m_negativeStyleSheet);
-        else if (iValue <= m_neutral) {
+        if (iValue <= m_negative) {
+            setStyleSheet(m_negativeStyleSheet);
+        } else if (iValue <= m_neutral) {
             setStyleSheet(m_neutralStyleSheet);
         } else if (iValue <= m_positive) {
             setStyleSheet(m_positiveStyleSheet);
         }
     } else {
-        if (iValue <= m_positive) setStyleSheet(m_positiveStyleSheet);
-        else if (iValue <= m_neutral) {
+        if (iValue <= m_positive) {
+            setStyleSheet(m_positiveStyleSheet);
+        } else if (iValue <= m_neutral) {
             setStyleSheet(m_neutralStyleSheet);
         } else if (iValue <= m_negative) {
             setStyleSheet(m_negativeStyleSheet);
